@@ -64,6 +64,11 @@ _VALID_SEMVER = r"""
 """.strip()
 _VALID_PVP = r"^\d+(\.\d+)*(-[a-zA-Z0-9]+)*$"
 
+_TIMESTAMP_GENERIC = "%Y-%m-%dT%H:%M:%S.%f%z"
+_TIMESTAMP_GENERIC_SPACE = "%Y-%m-%d %H:%M:%S.%f%z"
+_TIMESTAMP_GIT_ISO_STRICT = "%Y-%m-%dT%H:%M:%S%z"
+_TIMESTAMP_GIT_ISO = "%Y-%m-%d %H:%M:%S %z"
+
 _T = TypeVar("_T")
 
 
@@ -186,9 +191,7 @@ class Concern(Enum):
             return ""
 
 
-def _pattern_error(
-    primary: str, pattern: Union[str, Pattern], tags: Optional[Sequence[str]] = None
-) -> str:
+def _pattern_error(primary: str, pattern: Union[str, Pattern], tags: Optional[Sequence[str]] = None) -> str:
     parts = [primary, "Pattern:\n{}".format(pattern)]
 
     if tags is not None:
@@ -214,11 +217,7 @@ def _run_cmd(
     )
     output = result.stdout.decode().strip()
     if codes and result.returncode not in codes:
-        raise RuntimeError(
-            "The command '{}' returned code {}. Output:\n{}".format(
-                command, result.returncode, output
-            )
-        )
+        raise RuntimeError("The command '{}' returned code {}. Output:\n{}".format(command, result.returncode, output))
     return (result.returncode, output)
 
 
@@ -267,9 +266,7 @@ def _match_version_pattern(
         except re.error as e:
             raise re.error(
                 _pattern_error(
-                    "The pattern is an invalid regular expression: {}".format(
-                        e.msg  # type: ignore
-                    ),
+                    "The pattern is an invalid regular expression: {}".format(e.msg),  # type: ignore
                     pattern,
                 ),
                 e.pattern,  # type: ignore
@@ -283,9 +280,7 @@ def _match_version_pattern(
             if base is not None:
                 break
         except IndexError:
-            raise ValueError(
-                _pattern_error("The pattern did not include required capture group 'base'", pattern)
-            )
+            raise ValueError(_pattern_error("The pattern did not include required capture group 'base'", pattern))
     if pattern_match is None or base is None:
         if latest_source:
             raise ValueError(
@@ -315,9 +310,7 @@ def _match_version_pattern(
         except ValueError:
             raise ValueError("Epoch '{}' is not a valid number".format(epoch))
 
-    return _MatchedVersionPattern(
-        source, base, stage_revision, newer_unmatched_tags, tagged_metadata, epoch
-    )
+    return _MatchedVersionPattern(source, base, stage_revision, newer_unmatched_tags, tagged_metadata, epoch)
 
 
 def _blank(value: Optional[_T], default: _T) -> _T:
@@ -375,9 +368,7 @@ def _detect_vcs(expected_vcs: Optional[Vcs], path: Optional[Path]) -> Vcs:
         if code != 0:
             if expected_vcs == Vcs.Git and dubious_ownership_flag in msg:
                 raise RuntimeError(dubious_ownership_error)
-            raise RuntimeError(
-                "This does not appear to be a {} project".format(expected_vcs.value.title())
-            )
+            raise RuntimeError("This does not appear to be a {} project".format(expected_vcs.value.title()))
         return expected_vcs
     else:
         disproven = []
@@ -415,9 +406,7 @@ def _detect_vcs_from_archival(path: Optional[Path]) -> Optional[Vcs]:
     return None
 
 
-def _find_higher_file(
-    name: str, start: Optional[Path], limit: Optional[str] = None
-) -> Optional[Path]:
+def _find_higher_file(name: str, start: Optional[Path], limit: Optional[str] = None) -> Optional[Path]:
     """
     :param name: Bare name of a file we'd like to find.
     :param limit: Give up if we find a file/folder with this name.
@@ -435,9 +424,7 @@ def _find_higher_file(
 
 
 class _GitRefInfo:
-    def __init__(
-        self, ref: str, commit: str, creatordate: str, committerdate: str, taggerdate: str
-    ):
+    def __init__(self, ref: str, commit: str, creatordate: str, committerdate: str, taggerdate: str):
         self.fullref = ref
         self.commit = commit
         self.creatordate = self.normalize_git_dt(creatordate)
@@ -457,10 +444,7 @@ class _GitRefInfo:
             return _parse_git_timestamp_iso_strict(timestamp)
 
     def __repr__(self):
-        return (
-            "_GitRefInfo(ref={!r}, commit={!r}, creatordate={!r},"
-            " committerdate={!r}, taggerdate={!r})"
-        ).format(
+        return ("_GitRefInfo(ref={!r}, commit={!r}, creatordate={!r}, committerdate={!r}, taggerdate={!r})").format(
             self.fullref, self.commit_offset, self.creatordate, self.committerdate, self.taggerdate
         )
 
@@ -478,9 +462,7 @@ class _GitRefInfo:
             return self.tag_topo_lookup[self.fullref]
         except KeyError:
             raise RuntimeError(
-                "Unable to determine commit offset for ref {} in data: {}".format(
-                    self.fullref, self.tag_topo_lookup
-                )
+                "Unable to determine commit offset for ref {} in data: {}".format(self.fullref, self.tag_topo_lookup)
             )
 
     @property
@@ -499,19 +481,15 @@ class _GitRefInfo:
             return "refs/tags/{}".format(ref)
 
     @staticmethod
-    def from_git_tag_topo_order(
-        tag_branch: str, git_version: List[int], path: Optional[Path]
-    ) -> Mapping[str, int]:
-        cmd = (
-            '{} --simplify-by-decoration --topo-order --decorate=full {} "--format=%H%d"'
-        ).format(_git_log(git_version), tag_branch)
+    def from_git_tag_topo_order(tag_branch: str, git_version: List[int], path: Optional[Path]) -> Mapping[str, int]:
+        cmd = ('{} --simplify-by-decoration --topo-order --decorate=full {} "--format=%H%d"').format(
+            _git_log(git_version), tag_branch
+        )
         if git_version >= [2, 16]:
             cmd += " --decorate-refs=refs/tags/"
         code, logmsg = _run_cmd(cmd, path)
 
-        filtered_lines = [
-            x for x in logmsg.strip().splitlines(keepends=False) if " (" not in x or "tag: " in x
-        ]
+        filtered_lines = [x for x in logmsg.strip().splitlines(keepends=False) if " (" not in x or "tag: " in x]
 
         tag_lookup = {}
         for tag_offset, line in enumerate(filtered_lines):
@@ -522,9 +500,7 @@ class _GitRefInfo:
             if tags:
                 # remove trailing ')'
                 tags = tags[:-1]
-                taglist = [
-                    tag.strip() for tag in tags.split(", ") if tag.strip().startswith("tag: ")
-                ]
+                taglist = [tag.strip() for tag in tags.split(", ") if tag.strip().startswith("tag: ")]
                 taglist = [tag.split()[-1] for tag in taglist]
                 taglist = [_GitRefInfo.normalize_tag_ref(tag) for tag in taglist]
                 for tag in taglist:
@@ -637,9 +613,7 @@ class Version:
 
     def __eq__(self, other: Any) -> bool:
         if not isinstance(other, Version):
-            raise TypeError(
-                "Cannot compare Version with type {}".format(other.__class__.__qualname__)
-            )
+            raise TypeError("Cannot compare Version with type {}".format(other.__class__.__qualname__))
         return (
             self.base == other.base
             and self.stage == other.stage
@@ -676,9 +650,7 @@ class Version:
 
     def __lt__(self, other: Any) -> bool:
         if not isinstance(other, Version):
-            raise TypeError(
-                "Cannot compare Version with type {}".format(other.__class__.__qualname__)
-            )
+            raise TypeError("Cannot compare Version with type {}".format(other.__class__.__qualname__))
 
         import packaging.version as pv
 
@@ -731,6 +703,9 @@ class Version:
             * {branch}
             * {branch_escaped} which omits any non-letter/number characters
             * {timestamp} which expands to YYYYmmddHHMMSS as UTC
+            * {major} (first part of `base` split on `.`, or 0)
+            * {minor} (second part of `base` split on `.`, or 0)
+            * {patch} (third part of `base` split on `.`, or 0)
         :param style: Built-in output formats. Will default to PEP 440 if not
             set and no custom format given. If you specify both a style and a
             custom format, then the format will be validated against the
@@ -759,6 +734,8 @@ class Version:
                 out = format(new_version)
             else:
                 try:
+                    base_parts = base.split(".")
+
                     out = format.format(
                         base=base,
                         stage=_blank(self.stage, ""),
@@ -771,6 +748,9 @@ class Version:
                         branch=_blank(self.branch, ""),
                         branch_escaped=_escape_branch(_blank(self.branch, "")),
                         timestamp=self.timestamp.strftime("%Y%m%d%H%M%S") if self.timestamp else "",
+                        major=base_parts[0] if len(base_parts) > 0 else "0",
+                        minor=base_parts[1] if len(base_parts) > 1 else "0",
+                        patch=base_parts[2] if len(base_parts) > 2 else "0",
                     )
                 except KeyError as e:
                     raise KeyError("Format contains invalid placeholder: {}".format(e))
@@ -863,9 +843,7 @@ class Version:
 
         failed = False
         try:
-            matched_pattern = _match_version_pattern(
-                pattern, [normalized], True, strict=True, pattern_prefix=None
-            )
+            matched_pattern = _match_version_pattern(pattern, [normalized], True, strict=True, pattern_prefix=None)
         except ValueError:
             failed = True
 
@@ -1016,6 +994,7 @@ class Version:
         path: Optional[Path] = None,
         pattern_prefix: Optional[str] = None,
         ignore_untracked: bool = False,
+        commit_length: Optional[int] = None,
     ) -> "Version":
         r"""
         Determine a version based on Git tags.
@@ -1034,9 +1013,12 @@ class Version:
         :param pattern_prefix: Insert this after the pattern's start anchor (`^`).
         :param ignore_untracked:
             Ignore untracked files when determining whether the repository is dirty.
+        :param commit_length:
+            Use this many characters from the start of the full commit hash.
         :returns: Detected version.
         """
         vcs = Vcs.Git
+        full_commit = full_commit or commit_length is not None
 
         archival = _find_higher_file(".git_archival.json", path, ".git")
         if archival is not None:
@@ -1049,6 +1031,9 @@ class Version:
                 else:
                     commit = data.get("hash-short")
 
+                if commit is not None:
+                    commit = commit[:commit_length]
+
                 timestamp = None
                 raw_timestamp = data.get("timestamp")
                 if raw_timestamp:
@@ -1087,9 +1072,7 @@ class Version:
                         vcs=vcs,
                     )
 
-                matched_pattern = _match_version_pattern(
-                    pattern, [tag], latest_tag, strict, pattern_prefix
-                )
+                matched_pattern = _match_version_pattern(pattern, [tag], latest_tag, strict, pattern_prefix)
                 if matched_pattern is None:
                     return cls._fallback(
                         strict,
@@ -1144,28 +1127,20 @@ class Version:
             branch = msg
 
         code, msg = _run_cmd(
-            '{} -n 1 --format="format:{}"'.format(
-                _git_log(git_version), "%H" if full_commit else "%h"
-            ),
+            '{} -n 1 --format="format:{}"'.format(_git_log(git_version), "%H" if full_commit else "%h"),
             path,
             codes=[0, 128],
         )
         if code == 128:
-            return cls._fallback(
-                strict, distance=0, dirty=True, branch=branch, concerns=concerns, vcs=vcs
-            )
-        commit = msg
+            return cls._fallback(strict, distance=0, dirty=True, branch=branch, concerns=concerns, vcs=vcs)
+        commit = msg[:commit_length]
 
         timestamp = None
         if git_version < [2, 2]:
-            code, msg = _run_cmd(
-                '{} -n 1 --pretty=format:"%ci"'.format(_git_log(git_version)), path
-            )
+            code, msg = _run_cmd('{} -n 1 --pretty=format:"%ci"'.format(_git_log(git_version)), path)
             timestamp = _parse_git_timestamp_iso(msg)
         else:
-            code, msg = _run_cmd(
-                '{} -n 1 --pretty=format:"%cI"'.format(_git_log(git_version)), path
-            )
+            code, msg = _run_cmd('{} -n 1 --pretty=format:"%cI"'.format(_git_log(git_version)), path)
             timestamp = _parse_git_timestamp_iso_strict(msg)
 
         code, msg = _run_cmd("git describe --always --dirty", path)
@@ -1177,9 +1152,7 @@ class Version:
                 dirty = True
 
         if git_version < [2, 7]:
-            code, msg = _run_cmd(
-                'git for-each-ref "refs/tags/**" --format "%(refname)" --sort -creatordate', path
-            )
+            code, msg = _run_cmd('git for-each-ref "refs/tags/**" --format "%(refname)" --sort -creatordate', path)
             if not msg:
                 try:
                     code, msg = _run_cmd("git rev-list --count HEAD", path)
@@ -1197,13 +1170,10 @@ class Version:
                     vcs=vcs,
                 )
             tags = [line.replace("refs/tags/", "") for line in msg.splitlines()]
-            matched_pattern = _match_version_pattern(
-                pattern, tags, latest_tag, strict, pattern_prefix
-            )
+            matched_pattern = _match_version_pattern(pattern, tags, latest_tag, strict, pattern_prefix)
         else:
             code, msg = _run_cmd(
-                'git for-each-ref "refs/tags/**" --merged {}'.format(tag_branch)
-                + ' --format "%(refname)'
+                'git for-each-ref "refs/tags/**" --merged {}'.format(tag_branch) + ' --format "%(refname)'
                 "@{%(objectname)"
                 "@{%(creatordate:iso-strict)"
                 "@{%(*committerdate:iso-strict)"
@@ -1238,18 +1208,14 @@ class Version:
                 detailed_tags.append(_GitRefInfo(*parts).with_tag_topo_lookup(tag_topo_lookup))
 
             tags = [t.ref for t in sorted(detailed_tags, key=lambda x: x.sort_key, reverse=True)]
-            matched_pattern = _match_version_pattern(
-                pattern, tags, latest_tag, strict, pattern_prefix
-            )
+            matched_pattern = _match_version_pattern(pattern, tags, latest_tag, strict, pattern_prefix)
 
         if matched_pattern is None:
-            distance = 0
-
-            code, msg = _run_cmd("git rev-list --max-parents=0 HEAD", path)
-            if msg:
-                initial_commit = msg.splitlines()[0].strip()
-                code, msg = _run_cmd("git rev-list --count {}..HEAD".format(initial_commit), path)
+            try:
+                code, msg = _run_cmd("git rev-list --count HEAD", path)
                 distance = int(msg)
+            except Exception:
+                distance = 0
 
             return cls._fallback(
                 strict,
@@ -1292,6 +1258,7 @@ class Version:
         strict: bool = False,
         path: Optional[Path] = None,
         pattern_prefix: Optional[str] = None,
+        commit_length: Optional[int] = None,
     ) -> "Version":
         r"""
         Determine a version based on Mercurial tags.
@@ -1306,9 +1273,12 @@ class Version:
             When there are no tags, fail instead of falling back to 0.0.0.
         :param path: Directory to inspect, if not the current working directory.
         :param pattern_prefix: Insert this after the pattern's start anchor (`^`).
+        :param commit_length:
+            Use this many characters from the start of the full commit hash.
         :returns: Detected version.
         """
         vcs = Vcs.Mercurial
+        full_commit = full_commit or commit_length is not None
 
         archival = _find_higher_file(".hg_archival.txt", path, ".hg")
         if archival is not None:
@@ -1324,12 +1294,12 @@ class Version:
             # The distance is 1 on a new repo or on a tagged commit.
             distance = int(data.get("latesttagdistance", 1)) - 1
             commit = data.get("node")
+            if commit is not None:
+                commit = commit[:commit_length]
             branch = data.get("branch")
 
             if tag is None or tag == "null":
-                return cls._fallback(
-                    strict, distance=distance, commit=commit, branch=branch, vcs=vcs
-                )
+                return cls._fallback(strict, distance=distance, commit=commit, branch=branch, vcs=vcs)
 
             all_tags_file = _find_higher_file(".hgtags", path, ".hg")
             if all_tags_file is None:
@@ -1343,9 +1313,7 @@ class Version:
                         continue
                     all_tags.append(parts[1])
 
-            matched_pattern = _match_version_pattern(
-                pattern, all_tags, latest_tag, strict, pattern_prefix
-            )
+            matched_pattern = _match_version_pattern(pattern, all_tags, latest_tag, strict, pattern_prefix)
             if matched_pattern is None:
                 return cls._fallback(
                     strict,
@@ -1378,10 +1346,8 @@ class Version:
         code, msg = _run_cmd("hg branch", path)
         branch = msg
 
-        code, msg = _run_cmd(
-            'hg id --template "{}"'.format("{id}" if full_commit else "{id|short}"), path
-        )
-        commit = msg if set(msg) != {"0"} else None
+        code, msg = _run_cmd('hg id --template "{}"'.format("{id}" if full_commit else "{id|short}"), path)
+        commit = msg[:commit_length] if set(msg) != {"0"} else None
 
         code, msg = _run_cmd('hg log --limit 1 --template "{date|rfc3339date}"', path)
         timestamp = _parse_git_timestamp_iso_strict(msg) if msg != "" else None
@@ -1450,6 +1416,7 @@ class Version:
         strict: bool = False,
         path: Optional[Path] = None,
         pattern_prefix: Optional[str] = None,
+        commit_length: Optional[int] = None,
     ) -> "Version":
         r"""
         Determine a version based on Darcs tags.
@@ -1463,6 +1430,8 @@ class Version:
             When there are no tags, fail instead of falling back to 0.0.0.
         :param path: Directory to inspect, if not the current working directory.
         :param pattern_prefix: Insert this after the pattern's start anchor (`^`).
+        :param commit_length:
+            Use this many characters from the start of the full commit hash.
         :returns: Detected version.
         """
         vcs = Vcs.Darcs
@@ -1478,6 +1447,8 @@ class Version:
             timestamp = None
         else:
             commit = root[0].attrib["hash"]
+            if commit is not None:
+                commit = commit[:commit_length]
             timestamp = dt.datetime.strptime(root[0].attrib["date"] + "+0000", "%Y%m%d%H%M%S%z")
 
         code, msg = _run_cmd("darcs show tags", path)
@@ -1487,9 +1458,7 @@ class Version:
                 distance = int(msg)
             except Exception:
                 distance = 0
-            return cls._fallback(
-                strict, distance=distance, commit=commit, dirty=dirty, timestamp=timestamp, vcs=vcs
-            )
+            return cls._fallback(strict, distance=distance, commit=commit, dirty=dirty, timestamp=timestamp, vcs=vcs)
         tags = msg.splitlines()
 
         matched_pattern = _match_version_pattern(pattern, tags, latest_tag, strict, pattern_prefix)
@@ -1532,6 +1501,7 @@ class Version:
         strict: bool = False,
         path: Optional[Path] = None,
         pattern_prefix: Optional[str] = None,
+        commit_length: Optional[int] = None,
     ) -> "Version":
         r"""
         Determine a version based on Subversion tags.
@@ -1546,6 +1516,8 @@ class Version:
             When there are no tags, fail instead of falling back to 0.0.0.
         :param path: Directory to inspect, if not the current working directory.
         :param pattern_prefix: Insert this after the pattern's start anchor (`^`).
+        :param commit_length:
+            Use this many characters from the start of the full commit hash.
         :returns: Detected version.
         """
         vcs = Vcs.Subversion
@@ -1563,7 +1535,7 @@ class Version:
         if not msg or msg == "0":
             commit = None
         else:
-            commit = msg
+            commit = msg[:commit_length]
 
         timestamp = None
         if commit:
@@ -1571,9 +1543,7 @@ class Version:
             timestamp = _parse_timestamp(msg)
 
         if not commit:
-            return cls._fallback(
-                strict, distance=0, commit=commit, dirty=dirty, timestamp=timestamp, vcs=vcs
-            )
+            return cls._fallback(strict, distance=0, commit=commit, dirty=dirty, timestamp=timestamp, vcs=vcs)
         code, msg = _run_cmd('svn ls -v -r {} "{}/{}"'.format(commit, url, tag_dir), path)
         lines = [line.split(maxsplit=5) for line in msg.splitlines()[1:]]
         tags_to_revs = {line[-1].strip("/"): int(line[0]) for line in lines}
@@ -1582,14 +1552,10 @@ class Version:
                 distance = int(commit)
             except Exception:
                 distance = 0
-            return cls._fallback(
-                strict, distance=distance, commit=commit, dirty=dirty, timestamp=timestamp, vcs=vcs
-            )
+            return cls._fallback(strict, distance=distance, commit=commit, dirty=dirty, timestamp=timestamp, vcs=vcs)
         tags_to_sources_revs = {}
         for tag, rev in tags_to_revs.items():
-            code, msg = _run_cmd(
-                'svn log -v "{}/{}/{}" --stop-on-copy'.format(url, tag_dir, tag), path
-            )
+            code, msg = _run_cmd('svn log -v "{}/{}/{}" --stop-on-copy'.format(url, tag_dir, tag), path)
             for line in msg.splitlines():
                 match = re.search(r"A /{}/{} \(from .+?:(\d+)\)".format(tag_dir, tag), line)
                 if match:
@@ -1636,6 +1602,7 @@ class Version:
         strict: bool = False,
         path: Optional[Path] = None,
         pattern_prefix: Optional[str] = None,
+        commit_length: Optional[int] = None,
     ) -> "Version":
         r"""
         Determine a version based on Bazaar tags.
@@ -1649,6 +1616,8 @@ class Version:
             When there are no tags, fail instead of falling back to 0.0.0.
         :param path: Directory to inspect, if not the current working directory.
         :param pattern_prefix: Insert this after the pattern's start anchor (`^`).
+        :param commit_length:
+            Use this many characters from the start of the full commit hash.
         :returns: Detected version.
         """
         vcs = Vcs.Bazaar
@@ -1664,7 +1633,7 @@ class Version:
         for line in msg.splitlines():
             info = line.split("revno: ", maxsplit=1)
             if len(info) == 2:
-                commit = info[1]
+                commit = info[1][:commit_length]
 
             info = line.split("branch nick: ", maxsplit=1)
             if len(info) == 2:
@@ -1689,11 +1658,7 @@ class Version:
                 timestamp=timestamp,
                 vcs=vcs,
             )
-        tags_to_revs = {
-            line.split()[0]: int(line.split()[1])
-            for line in msg.splitlines()
-            if line.split()[1] != "?"
-        }
+        tags_to_revs = {line.split()[0]: int(line.split()[1]) for line in msg.splitlines() if line.split()[1] != "?"}
         tags = [x[1] for x in sorted([(v, k) for k, v in tags_to_revs.items()], reverse=True)]
 
         matched_pattern = _match_version_pattern(pattern, tags, latest_tag, strict, pattern_prefix)
@@ -1735,6 +1700,7 @@ class Version:
         strict: bool = False,
         path: Optional[Path] = None,
         pattern_prefix: Optional[str] = None,
+        commit_length: Optional[int] = None,
     ) -> "Version":
         r"""
         Determine a version based on Fossil tags.
@@ -1747,6 +1713,8 @@ class Version:
             When there are no tags, fail instead of falling back to 0.0.0.
         :param path: Directory to inspect, if not the current working directory.
         :param pattern_prefix: Insert this after the pattern's start anchor (`^`).
+        :param commit_length:
+            Use this many characters from the start of the full commit hash.
         :returns: Detected version.
         """
         vcs = Vcs.Fossil
@@ -1758,10 +1726,8 @@ class Version:
         code, msg = _run_cmd("fossil branch current", path)
         branch = msg
 
-        code, msg = _run_cmd(
-            "fossil sql \"SELECT value FROM vvar WHERE name = 'checkout-hash' LIMIT 1\"", path
-        )
-        commit = msg.strip("'")
+        code, msg = _run_cmd("fossil sql \"SELECT value FROM vvar WHERE name = 'checkout-hash' LIMIT 1\"", path)
+        commit = msg.strip("'")[:commit_length]
 
         code, msg = _run_cmd(
             'fossil sql "'
@@ -1827,8 +1793,7 @@ class Version:
             )
 
         tags_to_distance = [
-            (line.rsplit(",", 1)[0][5:-1], int(line.rsplit(",", 1)[1]) - 1)
-            for line in msg.splitlines()
+            (line.rsplit(",", 1)[0][5:-1], int(line.rsplit(",", 1)[1]) - 1) for line in msg.splitlines()
         ]
 
         matched_pattern = _match_version_pattern(
@@ -1872,6 +1837,7 @@ class Version:
         strict: bool = False,
         path: Optional[Path] = None,
         pattern_prefix: Optional[str] = None,
+        commit_length: Optional[int] = None,
     ) -> "Version":
         r"""
         Determine a version based on Pijul tags.
@@ -1885,6 +1851,8 @@ class Version:
             When there are no tags, fail instead of falling back to 0.0.0.
         :param path: Directory to inspect, if not the current working directory.
         :param pattern_prefix: Insert this after the pattern's start anchor (`^`).
+        :param commit_length:
+            Use this many characters from the start of the full commit hash.
         :returns: Detected version.
         """
         vcs = Vcs.Pijul
@@ -1905,7 +1873,7 @@ class Version:
         if len(limited_commits) == 0:
             return cls._fallback(strict, dirty=dirty, branch=branch, vcs=vcs)
 
-        commit = limited_commits[0]["hash"]
+        commit = limited_commits[0]["hash"][:commit_length]
         timestamp = _parse_timestamp(limited_commits[0]["timestamp"])
 
         code, msg = _run_cmd("pijul log --output-format json", path)
@@ -1936,7 +1904,7 @@ class Version:
                     tag_state = line.split("State ", 1)[1]
                 elif line.startswith("Date:"):
                     tag_timestamp = _parse_timestamp(
-                        line.split("Date: ", 1)[1].replace(" UTC", "Z"), space=True
+                        line.split("Date: ", 1)[1].replace(" UTC", "Z"), format=_TIMESTAMP_GENERIC_SPACE
                     )
                 elif line.startswith("    "):
                     tag_message += line[4:]
@@ -1958,9 +1926,7 @@ class Version:
                 else:
                     tag_message += line
         if tag_after_header:
-            tag_meta.append(
-                {"state": tag_state, "timestamp": tag_timestamp, "message": tag_message.strip()}
-            )
+            tag_meta.append({"state": tag_state, "timestamp": tag_timestamp, "message": tag_message.strip()})
 
         tag_meta_by_msg = {}  # type: dict
         for meta in tag_meta:
@@ -1970,10 +1936,7 @@ class Version:
             ):
                 tag_meta_by_msg[meta["message"]] = meta
 
-        tags = [
-            t["message"]
-            for t in sorted(tag_meta_by_msg.values(), key=lambda x: x["timestamp"], reverse=True)
-        ]
+        tags = [t["message"] for t in sorted(tag_meta_by_msg.values(), key=lambda x: x["timestamp"], reverse=True)]
 
         matched_pattern = _match_version_pattern(pattern, tags, latest_tag, strict, pattern_prefix)
         if matched_pattern is None:
@@ -2026,6 +1989,7 @@ class Version:
         path: Optional[Path] = None,
         pattern_prefix: Optional[str] = None,
         ignore_untracked: bool = False,
+        commit_length: Optional[int] = None,
     ) -> "Version":
         r"""
         Determine a version based on a detected version control system.
@@ -2058,6 +2022,8 @@ class Version:
         :param ignore_untracked:
             Ignore untracked files when determining whether the repository is dirty.
             This is only used for Git currently.
+        :param commit_length:
+            Use this many characters from the start of the full commit hash.
         :returns: Detected version.
         """
         vcs = _detect_vcs_from_archival(path)
@@ -2074,6 +2040,7 @@ class Version:
             path,
             pattern_prefix,
             ignore_untracked,
+            commit_length,
         )
 
     @classmethod
@@ -2089,6 +2056,7 @@ class Version:
         path: Optional[Path] = None,
         pattern_prefix: Optional[str] = None,
         ignore_untracked: bool = False,
+        commit_length: Optional[int] = None,
     ) -> "Version":
         r"""
         Determine a version based on a specific VCS setting.
@@ -2115,6 +2083,8 @@ class Version:
         :param ignore_untracked:
             Ignore untracked files when determining whether the repository is dirty.
             This is only used for Git currently.
+        :param commit_length:
+            Use this many characters from the start of the full commit hash.
         :returns: Detected version.
         """
         return cls._do_vcs_callback(
@@ -2128,6 +2098,7 @@ class Version:
             path,
             pattern_prefix,
             ignore_untracked,
+            commit_length,
         )
 
     @classmethod
@@ -2143,6 +2114,7 @@ class Version:
         path: Optional[Path],
         pattern_prefix: Optional[str] = None,
         ignore_untracked: bool = False,
+        commit_length: Optional[int] = None,
     ) -> "Version":
         mapping = {
             Vcs.Any: cls.from_any_vcs,
@@ -2166,6 +2138,7 @@ class Version:
             ("path", path),
             ("pattern_prefix", pattern_prefix),
             ("ignore_untracked", ignore_untracked),
+            ("commit_length", commit_length),
         ]:
             if kwarg in inspect.getfullargspec(callback).args:
                 kwargs[kwarg] = value
@@ -2379,21 +2352,16 @@ def bump_version(base: str, index: int = -1, increment: int = 1) -> str:
 def _parse_git_timestamp_iso_strict(raw: str) -> dt.datetime:
     # Remove colon from timezone offset for pre-3.7 Python:
     compat = re.sub(r"(.*T.*[-+]\d+):(\d+)", r"\1\2", raw)
-    return dt.datetime.strptime(compat, "%Y-%m-%dT%H:%M:%S%z")
+    return _parse_timestamp(compat, _TIMESTAMP_GIT_ISO_STRICT)
 
 
 def _parse_git_timestamp_iso(raw: str) -> dt.datetime:
     # Remove colon from timezone offset for pre-3.7 Python:
     compat = re.sub(r"(.* .* [-+]\d+):(\d+)", r"\1\2", raw)
-    return dt.datetime.strptime(compat, "%Y-%m-%d %H:%M:%S %z")
+    return _parse_timestamp(compat, _TIMESTAMP_GIT_ISO)
 
 
-def _parse_timestamp(raw: str, space: bool = False) -> dt.datetime:
-    if space:
-        format = "%Y-%m-%d %H:%M:%S.%f%z"
-    else:
-        format = "%Y-%m-%dT%H:%M:%S.%f%z"
-
+def _parse_timestamp(raw: str, format: str = _TIMESTAMP_GENERIC) -> dt.datetime:
     # Normalize "Z" for pre-3.7 compatibility:
     normalized = re.sub(r"Z$", "+0000", raw)
     # Truncate %f to six digits:
