@@ -66,7 +66,8 @@ common_sub_args = [
         "help": (
             "Custom output format. Available substitutions:"
             " {base}, {stage}, {revision}, {distance}, {commit}, {dirty},"
-            " {tagged_metadata}, {epoch}, {branch}, {branch_escaped}, {timestamp}"
+            " {tagged_metadata}, {epoch}, {branch}, {branch_escaped}, {timestamp},"
+            " {major}, {minor}, {patch}"
         ),
     },
     {
@@ -91,10 +92,7 @@ common_sub_args = [
         "action": "store_true",
         "dest": "strict",
         "default": False,
-        "help": (
-            "Elevate warnings to errors."
-            " When there are no tags, fail instead of falling back to 0.0.0"
-        ),
+        "help": ("Elevate warnings to errors. When there are no tags, fail instead of falling back to 0.0.0"),
     },
     {
         "triggers": ["--path"],
@@ -127,6 +125,12 @@ common_sub_args = [
         "default": False,
         "help": "Get the full commit hash instead of the short form",
     },
+    {
+        "triggers": ["--commit-length"],
+        "dest": "commit_length",
+        "type": int,
+        "help": "Use this many characters from the start of the full commit hash",
+    },
     {
         "vcs": [Vcs.Git],
         "triggers": ["--tag-branch"],
@@ -237,8 +241,12 @@ def build_parser(
     return parser
 
 
+def get_parser() -> argparse.ArgumentParser:
+    return build_parser(cli_spec)
+
+
 def parse_args(argv=None) -> argparse.Namespace:
-    return build_parser(cli_spec).parse_args(argv)
+    return get_parser().parse_args(argv)
 
 
 def from_stdin(value: Optional[str]) -> Optional[str]:
@@ -268,9 +276,21 @@ def from_vcs(
     strict: bool,
     path: Optional[Path],
     pattern_prefix: Optional[str],
+    ignore_untracked: bool,
+    commit_length: Optional[int],
 ) -> None:
     version = Version.from_vcs(
-        vcs, pattern, latest_tag, tag_dir, tag_branch, full_commit, strict, path, pattern_prefix
+        vcs,
+        pattern,
+        latest_tag,
+        tag_dir,
+        tag_branch,
+        full_commit,
+        strict,
+        path,
+        pattern_prefix,
+        ignore_untracked,
+        commit_length,
     )
 
     for concern in version.concerns:
@@ -290,6 +310,8 @@ def main() -> None:
             tag_dir = getattr(args, "tag_dir", "tags")
             tag_branch = getattr(args, "tag_branch", None)
             full_commit = getattr(args, "full_commit", False)
+            ignore_untracked = getattr(args, "ignore_untracked", False)
+            commit_length = getattr(args, "commit_length", None)
             from_vcs(
                 Vcs(args.vcs),
                 args.pattern,
@@ -307,6 +329,8 @@ def main() -> None:
                 args.strict,
                 Path(args.path) if args.path is not None else None,
                 args.pattern_prefix,
+                ignore_untracked,
+                commit_length,
             )
         elif args.command == "check":
             version = from_stdin(args.version)
